==> aselect-perl_2.1.orig.tar.xz: aselect-perl-2.1/lib/Aselect/UI/Document.pm <==
# $Id: Document.pm 36128 2011-11-30 13:05:49Z wsl $
# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Document.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Document;

use Xyzzy::Util qw(iso8601);

use Xyzzy::Document::XHTML -self;

sub getStylesheet {
	my $lang = $self->req->lang
		or return super;
	my $file = shift;
	return super("$lang/$file", @_);
}

sub transform {
	return if $self->req->raw;
	return super;
}

sub build {
	$self->hook_next;
	my $cfg = $self->cfg;
	my $req = $self->req;
	my $root = $self->documentElement;

	$root->appendChild($self->construct(settings =>
		[warn => $req->new_warn],
		[remember => $req->new_remember],
		[spnego => $req->new_spnego],
	));

	$root->appendChild($self->construct(nonce => $req->create_nonce));

	if(my $uid = $req->uid) {
		my $exp = $req->new_session->expiration;

		my $session = $self->construct(session =>
			[uid => $uid],
			[organization => $cfg->organization],
			[start => iso8601(localtime($exp))],
			[end => iso8601(localtime($exp + $cfg->session_timeout))],
		);

		$root->appendChild($session);
	}

	my $name = $root->nodeName;
	$name =~ tr|:|/|;
	eval { $self->transform($name) };
	warn $@ if $@;
}

sub bakecookie {
	my $cookie = super;
	if(my $domain = $self->cfg->cookiedomain) {
		$cookie->setparameter(Domain => $domain);
	}
	return $cookie;
}

sub response {
	my $res = super;
	my $req = $self->req;

	my $session = $req->new_session->token;
	my $previous = $req->cur_session;
	unless($previous && $previous->token eq $session) {
		my $cookie = $self->bakecookie(session => $session);
		$cookie->setparameter(HttpOnly => 1);
		$res->setcookie($cookie);
	}

	my $sts = $self->cfg->strict_transport_security;
	$res->setheader('Strict-Transport-Security' => "max-age=$sts")
		if $sts && $req->https eq 'on';

	# DOM/XSL system protects against XSS
	$res->setheader('X-XSS-Protection' => 0);

	# Don't try to second guess the content type
	$res->setheader('X-Content-Type-Options' => 'nosniff');

	# Protect against clickjacking
	$res->setheader('X-Frame-Options' => 'DENY');

	$res->mimetype('application/xml')
		if $req->raw;

	return $res;
}

==> aselect-perl_2.5.tar.xz: aselect-perl-2.5/lib/Aselect/UI/Document.pm <==
# $Id: Document.pm 36341 2012-01-15 18:20:01Z wsl $
# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Document.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Document;

use Xyzzy::Util qw(iso8601);

use Xyzzy::Document::XHTML -self;

sub getStylesheet {
	my $lang = $self->req->lang
		or return super;
	my $file = shift;
	return super("$lang/$file", @_);
}

sub transform {
	return if $self->req->raw;
	return super;
}

sub build {
	$self->hook_next;
	my $cfg = $self->cfg;
	my $req = $self->req;
	my $root = $self->documentElement;

	$root->appendChild($self->construct(settings =>
		[warn => $req->new_warn],
		[remember => $req->new_remember],
		[spnego => $req->new_spnego],
	));

	my $ticket = $req->new_session;
	$root->appendChild($self->construct(nonce => scalar $ticket->create_nonce));

	if(my $uid = $ticket->uid) {
		my $exp = $ticket->expiration;

		my $session = $self->construct(session =>
			[uid => $uid],
			[organization => $cfg->organization],
			[start => iso8601(localtime($exp))],
			[end => iso8601(localtime($exp + $cfg->session_timeout))],
		);

		$root->appendChild($session);
	}

	my $name = $root->nodeName;
	$name =~ tr|:|/|;
	eval { $self->transform($name) };
	warn $@ if $@;
}

sub bakecookie {
	my $cookie = super;
	if(my $domain = $self->cfg->cookiedomain) {
		$cookie->setparameter(Domain => $domain);
	}
	return $cookie;
}

sub response {
	my $res = super;
	my $req = $self->req;

	my $session = $req->new_session->token;
	my $previous = $req->cur_session;
	unless($previous && $previous->token eq $session) {
		my $cookie = $self->bakecookie(session => $session);
		$cookie->setparameter(HttpOnly => 1);
		$res->setcookie($cookie);
	}

	my $sts = $self->cfg->strict_transport_security;
	$res->setheader('Strict-Transport-Security' => "max-age=$sts")
		if $sts && $req->https eq 'on';

	# DOM/XSL system protects against XSS
	$res->setheader('X-XSS-Protection' => 0);

	# Don't try to second guess the content type
	$res->setheader('X-Content-Type-Options' => 'nosniff');

	# Protect against clickjacking
	$res->setheader('X-Frame-Options' => 'DENY');

	$res->mimetype('application/xml')
		if $req->raw;

	return $res;
}
